@@ -31,6 +31,8 @@ const QString KBlacklistFile = "/root/.fapman/black.list";
 const QString KOwnRepoFile = "/root/.fapman/repos.list";
 const QString KOwnRepoNamesFile = "/root/.fapman/repos.names";
 
+const QString KDefaultUserOpenSaveDir = "/home/user/MyDocs";
+
 #ifdef Q_WS_MAEMO_5
 	const QString KHamRepoListFile = "/etc/apt/sources.list.d/hildon-application-manager.list";
 #else
@@ -102,8 +104,6 @@ public:
 	void setSkipListAndDates() { iSkipRefreshListAndDates=true; }
 	bool needListOrDateRefresh();
 
-	bool loadInstallFiles(QStringList files_);
-
 	QDateTime lastListUpdate() { return iLastListUpdate; }
 	QDateTime lastDpkgUpdate() { return iLastDpkgUpdate; }
 
