@@ -32,13 +32,17 @@ class LogView : public QDialog
 
 public:
 	explicit LogView(QByteArray text, QWidget *parent = 0);
-    ~LogView();
+	virtual ~LogView();
+
 	int exec();
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
+	LogView(const LogView& old);
+	LogView operator= (const LogView& old);
+
     Ui::LogView *ui;
 
 private slots:
