@@ -35,7 +35,9 @@ class RepoEdit : public QDialog
 
 public:
 	explicit RepoEdit(AAptInterface* apt, Repository* repo, int pos, QWidget *parent = 0);
-    ~RepoEdit();
+	virtual ~RepoEdit();
+
+	/*
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	int exec() {
 		QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
@@ -46,12 +48,15 @@ public:
 		return e;
 	}
 #endif
-
+	*/
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
+	RepoEdit(const RepoEdit& old);
+	RepoEdit operator= (const RepoEdit& old);
+
     Ui::RepoEdit *ui;
 	Repository* iRepo;
 	int iPos;
