@@ -32,6 +32,11 @@ public:
 
 	void setName(QString n_) { iName=n_; }
 	void setEnabled(bool e_) { iEnabled=e_; }
+    void setUrl(QString url_) { iUrl = url_; }
+    void setDir(QString dir_) { iDir = dir_; }
+    void setComponents(QString cmp_) { iComponents = cmp_; }
+    void setDist(QString d_) { iDist = d_; }
+    void setUrlDir(QString url_dir);
 
 	QString name() const { return iName; }
 	QString url() const { return iUrl; }
@@ -39,7 +44,7 @@ public:
 	QString dist() const { return iDist; }
 	QString components() const { return iComponents; }
 	bool enabled() const { return iEnabled; }
-	QString toString() const;
+    QString toString(bool noDisable=false) const;
 	QStringList toListFileNames() const;
 	bool setFromString(QString repo);
 	void set(QString name, QString url, QString dir_dist, QString components, bool enabled);
